=========
Changelog
=========

latest
======

- add support for simple Postgres Cluster as backend


v0.1.9
======

- added authentication to delete resource

v0.1.8
======

- added init script
- fixed postgraas to 9.4

v0.1.7
======

- fixed docker version 1.12

v0.1.6
======

- bugfix: password was not set in instance

v0.1.5
======

- automated release process via travis
- fixed meta db initialization

v0.1.4
======

- removed postgraas instance one and fixed the tests

v0.1.3
======

- Introduced completely new API v2

v0.1.0
======

- First running version


